from setuptools import setup

setup(name='menday.distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author = 'Stewart Menday',
      author_email = 'stewart@menday.com.au',
      zip_safe=False)
